@@ -754,7 +754,7 @@ async def websocket_execute(websocket: WebSocket):
 
                 llm_response = await server.engine.llm_provider.complete_with_usage(
                     prompt=assembled_prompt,
-                    streaming_callback=streaming_callback
+                    on_token=streaming_callback  # Fixed: use on_token parameter
                 )
 
                 execution_time = time.time() - start_time
@@ -799,12 +799,13 @@ async def websocket_execute(websocket: WebSocket):
 
                 # Skip the standard execution flow - we already have the result
                 # Send completion immediately
+                # NOTE: Don't include "result" field - tokens already streamed via streaming_callback
                 display_function_name = display_name
                 await websocket.send_json({
                     "type": "complete",
                     "success": result.success,
                     "function_name": display_function_name,
-                    "result": result.message,
+                    # "result": result.message,  # Omit - already streamed token-by-token
                     "data": result.data,
                     "metadata": format_completion_metadata(result)
                 })
